(function (global, factory) {
	typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('vue/dist/vue.js')) :
	typeof define === 'function' && define.amd ? define(['exports', 'vue/dist/vue.js'], factory) :
	(factory((global.vueTest = global.vueTest || {}),global.Vue));
}(this, (function (exports,Vue) { 'use strict';

Vue = 'default' in Vue ? Vue['default'] : Vue;

/*!
 * dashify <https://github.com/jonschlinkert/dashify>
 *
 * Copyright (c) 2015 Jon Schlinkert.
 * Licensed under the MIT license.
 */

var index = function dashify(str) {
  if (typeof str !== 'string') {
    throw new TypeError('expected a string');
  }
  str = str.replace(/([a-z])([A-Z])/g, '$1-$2');
  str = str.replace(/[ \t\W]/g, '-');
  str = str.replace(/^-+|-+$/g, '');
  return str.toLowerCase();
};

/**
 * Get a given attribute from the first element.
 *
 * @param {string} attrName The name of the attribute.
 * @returns {string|null} The value of the attribute, or null.
 */
function attr(attrName) {
  return this._el[0].getAttribute(attrName);
}

/**
 * Get a given data attribute from the first element.
 *
 * @param {string} attrName The name of the data attribute.
 * @returns {string|null} The value of the data attribute, or undefined.
 */
function data(attrName) {
  return this._el[0].dataset[attrName];
}

/**
 * Get the HTML of the first element.
 *
 * @returns {string} The HTML.
 */
function html() {
  return this._el[0].outerHTML;
}

/**
 * Get a given property from the first element.
 *
 * @param {string} propName The name of the property.
 * @returns {boolean} True or false.
 */
function prop(propName) {
  return this._el[0][propName];
}

/**
 * Get the text contained within an element.
 *
 * @returns {string} The text.
 */
function text() {
  return this._el[0].textContent;
}

/**
 * Get the value of an input element.
 *
 * @returns {text} The value.
 */
function value() {
  return this._el[0].value;
}

var attributeFns = Object.freeze({
	attr: attr,
	data: data,
	html: html,
	prop: prop,
	text: text,
	value: value
});

/**
 * Trigger event on the mounted elements.
 *
 * @param {string|Event} event Name of event to fire, or event object.
 */
function trigger(event) {
  Array.from(this._el).forEach(function (el) {
    if (!(event instanceof Event)) {
      event = new Event(event);
    }

    el.dispatchEvent(event);
  });
}

var eventFns = Object.freeze({
	trigger: trigger
});

/**
 * Equivalent to array.forEach().
 *
 * @param {function} cb A predicate function.
 * @returns {MountedComponent} self.
 */
function each(cb) {
  var _this = this;

  Array.from(this._el).forEach(function (el, i) {
    var elMount = _this._newFromThis(el);
    cb.call(elMount, i, elMount);
  });

  return this;
}

/**
 * Equivalent to array.map().
 *
 * @param {function} cb A predicate function.
 * @returns {Array} Array of values returned by predicate function.
 */
function map(cb) {
  var _this2 = this;

  return Array.from(this._el).map(function (el, i) {
    var elMount = _this2._newFromThis(el);
    return cb.call(elMount, i, elMount);
  });
}

/**
 * Equivalent to array.some().
 *
 * @param {function} cb A predicate function.
 * @returns {boolean} True if predicate function returns true at least once.
 */
function some(cb) {
  var _this3 = this;

  return Array.from(this._el).some(function (el, i) {
    var elMount = _this3._newFromThis(el);
    return cb.call(elMount, i, elMount);
  });
}

/**
 * Equivalent to array.every().
 *
 * @param {function} cb A predicate function.
 * @returns {boolean} True if predicate function returns true every time.
 */
function every(cb) {
  var _this4 = this;

  return Array.from(this._el).every(function (el, i) {
    var elMount = _this4._newFromThis(el);
    return cb.call(elMount, i, elMount);
  });
}

var iterationFns = Object.freeze({
	each: each,
	map: map,
	some: some,
	every: every
});

/**
 * Get element or (if no argument) array of elements.
 *
 * @param {number} [n] Index of element to get.
 * @returns {Array|HTMLElement|null} Array of elements or element.
 */
function get(n) {
  if (typeof n === 'undefined') {
    return Array.from(this._el);
  }

  return this._el[n] || null;
}

/**
 * Get an element as a MountedComponent.
 *
 * @param {number} n Index of element to get.
 * @returns {MountedComponent|null} New MountedComponent.
 */
function eq(n) {
  if (!this._el[n]) {
    return null;
  }

  return this._newFromThis(this._el[n]);
}

/**
 * Filter elements using a predicate function.
 *
 * @param {function} cb Predicate function: return truthy to keep element.
 * @returns {MountedComponent} Subset MountedComponent. Can be empty.
 */
function filter(cb) {
  var _this = this;

  var subset = Array.from(this._el).filter(function (el, i) {
    var elMount = _this._newFromThis(el);

    return cb.call(elMount, i, elMount);
  });

  return this._newFromThis(subset);
}

var subsetFns = Object.freeze({
	get: get,
	eq: eq,
	filter: filter
});

var proto = Element.prototype;
var vendor = proto.matches || proto.matchesSelector || proto.webkitMatchesSelector || proto.mozMatchesSelector || proto.msMatchesSelector || proto.oMatchesSelector;

var index$1 = match;

/**
 * Match `el` to `selector`.
 *
 * @param {Element} el
 * @param {String} selector
 * @return {Boolean}
 * @api public
 */

function match(el, selector) {
  if (vendor) return vendor.call(el, selector);
  var nodes = el.parentNode.querySelectorAll(selector);
  for (var i = 0; i < nodes.length; i++) {
    if (nodes[i] == el) return true;
  }
  return false;
}

/**
 * Test whether an element has a given class or not.
 *
 * @param {string} className The name of the class to test for.
 * @returns {boolean} True if the element has the class.
 */
function hasClass(className) {
  return Array.from(this._el).some(function (el) {
    return el.classList.contains(className);
  });
}

/**
 * Test whether an element matches a given selector or not.
 *
 * @param {string} selector Selector to use.
 * @returns {boolean} True if an element matches the selector.
 */
function matches(selector) {
  return Array.from(this._el).some(function (el) {
    return index$1(el, selector);
  });
}

/**
 * Test whether an element contains a given selector or not.
 *
 * @param {string} selector Selector to use.
 * @returns {boolean} True if an element matches the selector.
 */
function contains(selector) {
  return Array.from(this._el).some(function (el) {
    return el.querySelectorAll(selector).length;
  });
}

/**
 * Tests whether an element has no child nodes (including text and whitespace)
 *
 * @returns {boolean} True if element is empty.
 */
function isEmpty() {
  return !Array.from(this._el).some(function (el) {
    return el.childNodes.length;
  });
}

var testFns = Object.freeze({
	hasClass: hasClass,
	matches: matches,
	contains: contains,
	isEmpty: isEmpty
});

var toConsumableArray = function (arr) {
  if (Array.isArray(arr)) {
    for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) arr2[i] = arr[i];

    return arr2;
  } else {
    return Array.from(arr);
  }
};

/**
 * Find all elements within the mounted element(s) matching a given selector.
 *
 * @param {string} selector The selector to use.
 * @returns {MountedComponent} A new MountedComponent.
 */
exports.find = function componentFind(selector) {
  var found = [];

  Array.from(this._el).forEach(function (el) {
    found.push.apply(found, toConsumableArray(el.querySelectorAll(selector)));
  });

  if (!found.length) {
    return null;
  }

  return this._newFromThis(found);
};

/**
 * Find all children of mounted element(s), optionally matching a given
 * selector.
 *
 * @param {string} [selector] The selector to filter by.
 * @returns {MountedComponent} A new MountedComponent.
 */
exports.children = function componentChildren(selector) {
  var children = [];

  Array.from(this._el).forEach(function (el) {
    var _children;

    return (_children = children).push.apply(_children, toConsumableArray(el.children));
  });

  if (selector) {
    children = children.filter(function (child) {
      return index$1(child, selector);
    });
  }

  if (!children.length) {
    return null;
  }

  return this._newFromThis(children);
};

/**
 * Returns the parent of a mounted element. Will search upwards until it finds
 * a parent matching the given selector.
 *
 * @returns {MountedComponent} A new MountedComponent.
 */
exports.parent = function componentParent(selector) {
  var parent = this._el[0].parentElement;

  if (!selector) {
    return this._newFromThis(parent);
  }

  while (parent && !index$1(parent, selector)) {
    parent = parent.parentElement;
  }

  if (!parent) {
    return null;
  }

  return this._newFromThis(parent);
};



var traversalFns = Object.freeze({

});

function MountedComponent() {}

Object.defineProperty(MountedComponent.prototype, 'length', {
  get: function get$$1() {
    return this._el.length;
  },

  enumerable: true
});

/**
 * Initialise a new component with a vm and elements. Used internally by the
 * `mount()` function.
 *
 * @param {Object} TestComponent A Vue component to mount.
 * @param {Object} [props] An optional objects containing properties to pass.
 * @param {string} [slot] Optional slot content as a string.
 * @private
 */
MountedComponent.prototype._init = function initMountedComponent(TestComponent) {
  var props = arguments.length <= 1 || arguments[1] === undefined ? {} : arguments[1];
  var slot = arguments.length <= 2 || arguments[2] === undefined ? '' : arguments[2];

  // If propsString makes you say wtf, please +1 the following issue:
  // https://github.com/vuejs/vue/issues/2114
  var propsString = Object.keys(props).map(function (prop$$1) {
    return ':' + index(prop$$1) + '="' + prop$$1 + '"';
  }).join(' ');

  this._vm = new Vue({
    template: '<div><test-component ' + propsString + '>' + slot + '</test-component></div>',
    components: { TestComponent: TestComponent },
    data: props
  }).$mount();

  this._el = this._vm.$el.children;
};

/**
 * Generate a new MountedComponent in the same VM, but with different elements.
 *
 * @param {Array|HTMLElement} el HTML element (or array of)
 * @returns {MountedComponent} New MountedComponent.
 * @private
 */
MountedComponent.prototype._newFromThis = function newFromThis(el) {
  var elMount = new MountedComponent();
  elMount._vm = this._vm;
  elMount._el = Array.isArray(el) ? el : [el];

  return elMount;
};

Object.assign(MountedComponent.prototype, attributeFns);
Object.assign(MountedComponent.prototype, eventFns);
Object.assign(MountedComponent.prototype, iterationFns);
Object.assign(MountedComponent.prototype, subsetFns);
Object.assign(MountedComponent.prototype, testFns);
Object.assign(MountedComponent.prototype, traversalFns);

function attribute(chai, utils) {
  var Assertion = chai.Assertion;

  Assertion.addChainableMethod('attribute', function (attribute) {
    var obj = this._obj;

    new Assertion(obj).to.be.instanceof(MountedComponent);
    new Assertion(attribute).to.be.ok;

    utils.flag(this, 'vue.attribute', attribute);

    this.assert(obj.matches('[' + attribute + ']'), 'expected Vue component to have attribute #{exp}', 'expected Vue component to not have attribute #{exp}', attribute);
  });

  Assertion.addMethod('equals', function (expected) {
    var obj = this._obj;

    new Assertion(obj).to.be.instanceof(MountedComponent);
    var attribute = utils.flag(this, 'vue.attribute');
    new Assertion(attribute).to.be.ok;

    this.assert(obj.attr(attribute) === expected, 'expected attribute ' + attribute + ' to equal #{exp}, got #{act}', 'expected attribute ' + attribute + ' to not equal #{exp}', attribute, obj.attr(attribute));
  });
}

function className(chai, utils) {
  var Assertion = chai.Assertion;

  Assertion.addMethod('className', function (className) {
    var obj = this._obj;

    new Assertion(className).to.not.contain(' ', 'invalid classname');
    new Assertion(obj).to.be.instanceof(MountedComponent);

    var containsFlag = utils.flag(this, 'contains');

    if (containsFlag) {
      this.assert(obj.find('.' + className), 'expected Vue component to contain element with className #{exp}', 'expected Vue component to not contain element with className #{exp}', className);
    } else {
      this.assert(obj.hasClass(className), 'expected Vue component to have className #{exp} (#{act})', 'expected Vue component to not have className #{exp}', className, obj.attr('class'));
    }
  });
}

function empty(chai) {
  var Assertion = chai.Assertion;

  Assertion.overwriteProperty('empty', function (_super) {
    return function () {
      var obj = this._obj;

      if (obj instanceof MountedComponent) {
        this.assert(obj.isEmpty(), 'expected Vue component to be empty', 'expected Vue component to not be empty');
      } else {
        _super.call(this);
      }
    };
  });
}

function match$1(chai, utils) {
  var Assertion = chai.Assertion;

  Assertion.addChainableMethod('match', function (selector) {
    var obj = this._obj;

    new Assertion(obj).to.be.instanceof(MountedComponent);
    new Assertion(selector).to.be.ok;

    this.assert(obj.matches(selector), 'expected Vue component to match selector #{exp}', 'expected Vue component to not match selector #{exp}', selector);
  }, function () {
    utils.flag(this, 'vue.match', true);
  });
}

function selector(chai, utils) {
  var Assertion = chai.Assertion;

  Assertion.addMethod('selector', function (selector) {
    var obj = this._obj;

    new Assertion(obj).to.be.instanceof(MountedComponent);
    new Assertion(selector).to.be.ok;

    if (utils.flag(this, 'vue.match')) {
      this.match(selector);
      return;
    }

    if (utils.flag(this, 'contains')) {
      this.assert(obj.contains(selector), 'expected Vue component to contain selector #{exp}', 'expected Vue component to not contain selector #{exp}', selector);
      return;
    }

    throw new Error('you need to specify either contains or matches');
  });
}

function tag(chai, utils) {
  var Assertion = chai.Assertion;

  Assertion.addMethod('tag', function (tagName) {
    var obj = this._obj;

    new Assertion(obj).to.be.instanceof(MountedComponent);

    var containsFlag = utils.flag(this, 'contains');

    if (containsFlag) {
      this.assert(obj.find(tagName), 'expected Vue component to contain tagName #{exp}', 'expected Vue component to not contain tagName #{exp}', tagName);
    } else {
      this.assert(obj.get(0).tagName === tagName.toUpperCase(), 'expected Vue component to have tagName #{exp} but got #{act}', 'expected Vue component to not have tagName #{exp}', tagName.toUpperCase(), obj.get(0).tagName);
    }
  });
}

function text$1(chai, utils) {
  var Assertion = chai.Assertion;

  Assertion.addMethod('text', function (text) {
    var obj = this._obj;

    new Assertion(obj).to.be.instanceof(MountedComponent);

    var containsFlag = utils.flag(this, 'contains');

    if (containsFlag) {
      this.assert(obj.text().indexOf(text) !== -1, 'expected Vue component to contain text #{exp}', 'expected Vue component to not contain text #{exp}', text);
    } else {
      this.assert(obj.text() === text, 'expected Vue component to have text #{exp} but got #{act}', 'expected Vue component to not have text #{exp}', text, obj.text());
    }
  });
}

function value$1(chai, utils) {
  var Assertion = chai.Assertion;

  Assertion.addMethod('value', function (value) {
    var obj = this._obj;

    new Assertion(obj).to.be.instanceof(MountedComponent);

    this.assert(obj.value() === value, 'expected Vue component to have value #{exp} but got #{act}', 'expected Vue component to not have value #{exp}', value, obj.value());
  });
}

/**
 * Shortcut to add all plugins.
 */
function chaiPlugin(chai) {
  Object.keys(plugins).forEach(function (plugin) {
    chai.use(plugins[plugin]);
  });
}

var plugins = {
  attribute: attribute, className: className, empty: empty, match: match$1, selector: selector, tag: tag, text: text$1, value: value$1
};

/**
 * Mount a given component with optional props, returning a MountedComponent
 * object with methods like `.text()` and `.find()`.
 *
 * @param {Object} TestComponent A Vue component to mount.
 * @param {Object} [props] An optional objects containing properties to pass.
 * @param {string} [slot] Optional slot content as a string.
 * @returns {MountedComponent}
 */
function mount(TestComponent, props, slot) {
  var mounted = new MountedComponent();
  mounted._init(TestComponent, props, slot);
  return mounted;
}

/**
 * Returns a function that creates new mounted instances of a components.
 *
 * @param {Object} TestComponent A Vue component to mount.
 * @returns {function([props], [slot]): MountedComponent} Function with
 * props and slot arguments.
 */
function createMounter(TestComponent) {
  return function (props, slot) {
    return mount(TestComponent, props, slot);
  };
}

exports.mount = mount;
exports.createMounter = createMounter;
exports.chaiPlugin = chaiPlugin;

Object.defineProperty(exports, '__esModule', { value: true });

})));
//# sourceMappingURL=index.js.map
